TxBuilder class

Allows to easily build and sign a StdTx that can later be sent over the network.

Constructors

TxBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildStdTx({required List<StdMsg> stdMsgs, String memo = '', StdFee fee = const StdFee(gas: '200000', amount: [])}) → StdTx
Builds a StdTx object containing the given stdMsgs and having the optional memo and fee specified.